#
# spec file for package whois
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           whois
Version:        5.5.18
Release:        1.2
Summary:        Intelligent WHOIS client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/rfc1036/whois
Source:         https://ftp.debian.org/debian/pool/main/w/whois/%{name}_%{version}.tar.xz
Source2:        https://ftp.debian.org/debian/pool/main/w/whois/%{name}_%{version}.dsc#/%{name}.asc
Source3:        https://db.debian.org/fetchkey.cgi?fingerprint=6791403B68AE2690517C42EAE6FFF1E38DC968B0#/%{name}.keyring
Patch0:         whois-nobsdsource.patch
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(libidn2)
Provides:       ripe-whois-tools
%{perl_requires}
%if 0%{?suse_version} != 1310
BuildRequires:  perl(autodie)
%endif

%description
This package provides a commandline client for the WHOIS (RFC 3912)
protocol, which queries online servers for information such as contact
details for domains and IP address assignments.
It can intelligently select the appropriate WHOIS server for most queries.

The package also contains mkpasswd, a features-rich front end to the
password encryption function crypt(3).

%package bash-completion
Summary:        Bash completion for whois
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
bash command line completion support for whois.

%prep
# the signature is on the Debian .dsc. Extract the checksums and verify against source
echo "`grep -A1 "Files:" %{SOURCE2} | grep %{name}_%{version}.tar.xz | cut -d\  -f2`  %{SOURCE0}" | md5sum -c
echo "`grep -A1 "Checksums-Sha1" %{SOURCE2} | grep %{name}_%{version}.tar.xz | cut -d\  -f2`  %{SOURCE0}" | sha1sum -c
echo "`grep -A1 "Checksums-Sha256" %{SOURCE2} | grep %{name}_%{version}.tar.xz | cut -d\  -f2`  %{SOURCE0}" | sha256sum -c

%autosetup -p1

%build
%make_build all mkpasswd HAVE_LIBIDN2=1 HAVE_ICONV=1 \
%if 0%{?suse_version} <= 1140
	HAVE_XCRYPT=1 \
%else
	HAVE_CRYPT_GENSALT=1 \
%endif
	CFLAGS="%{optflags}"

%install
mkdir -p %{buildroot}{%{_prefix}/bin,%{_mandir}/man1}
make BASEDIR=%{buildroot} mandir=%{_mandir} prefix=%{_prefix} \
	install install-mkpasswd install-pos
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README debian/changelog
%{_bindir}/mkpasswd
%{_bindir}/whois
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man5/*.5%{?ext_man}

%files bash-completion
%{_sysconfdir}/bash_completion.d/whois
%{_sysconfdir}/bash_completion.d/mkpasswd

%changelog
* Wed Jul 26 2023 Dirk Müller <dmueller@suse.com>
- update to 5.5.18:
  * Updated the .ga TLD server. (Closes: #1037288)
  * Added new recovered IPv4 allocations.
  * Removed the delegation of 43.0.0.0/8 to JPNIC.
  * Removed 12 new gTLDs which are no longer active.
  * Improved the man page source, courtesy of Bjarni Ingi
    Gislason.
  * Added the .edu.za SLD server.
  * Updated the .alt.za SLD server.
  * Added the -ru and -su NIC handles servers.
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 5.5.17:
  * Added the .cd TLD server.
  * Updated the -kg NIC handles server name.
  * Removed 2 new gTLDs which are no longer active.
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 5.5.16:
  * Add bash completion support, courtesy of Ville Skyttä.
  * Updated the .tr TLD server.
  * Removed support for -metu NIC handles.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 5.5.15:
  * Updated the .bd, .nz and .tv TLD servers.
  * Added the .llyw.cymru, .gov.scot and .gov.wales SLD servers.
  * Updated the .ac.uk and .gov.uk SLD servers.
  * Recursion has been enabled for whois.nic.tv.
  * Updated the list of new gTLDs with four generic TLDs assigned in
    October 2013 which were missing due to a bug.
  * Removed 4 new gTLDs which are no longer active.
  * Added the Georgian translation, contributed by Temuri Doghonadze.
  * Updated the Finnish translation, contributed by Lauri Nurmi.
* Mon Oct 17 2022 Dirk Müller <dmueller@suse.com>
- update to 5.5.14:
  * Added the .bf and .sd TLD servers.
  * Removed the .gu TLD server.
  * Updated the .dm, .fj, .mt and .pk TLD servers.
  * Updated the charset for whois.nic.tr.
  * Updated the list of new gTLDs.
  * Removed whois.nic.fr from the list of RIPE-like servers, because it
    is not one anymore. (Closes: #1021110)
  * Renamed whois.arnes.si to whois.register.si in the list of RIPE-like
    servers.
  * Added the hiding string for whois.auda.org.au.
* Fri Apr  8 2022 Dirk Müller <dmueller@suse.com>
- update to 5.5.13:
  * Added the .sd TLD server.
  * Updated the list of new gTLDs.
  * Added the Turkish translation, contributed by Oğuz Ersen.
* Thu Feb 24 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to 5.5.12:
  * Updated the .pro TLD server, which was totally broken.
  * Fixed the detection of Japanese locales using $LC_MESSAGES.
  * Implemented providing partial salt strings to mkpasswd.
  * Removed 2 new gTLDs which are no longer active.
  * Updated one or more translations.
  * Enabled full hardening in debian/rules.
- Cleanup build requirements for SLE-11
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 5.5.11:
  * Implemented a --no-recursion command line option to disable recursion
    from registrar to registry servers.
  * Updated the .pro, .vu and .xxx TLD servers.
  * Updated the list of new gTLDs.
  * Removed 7 new gTLDs which are no longer active.
* Mon Jul  5 2021 Dirk Müller <dmueller@suse.com>
- update to 5.5.10:
  * Updated the .lb TLD server.
  * Removed 5 new gTLDs which are no longer active.
  * Updated the charset for whois.lacnic.net, whois.ax, whois.cira.ca
    and whois.dns.pt.
  * Fixed reporting an older version number when using --version.
* Fri Apr  2 2021 Wang Jun <jgwang@suse.com>
- update to 5.5.9:
  * Updated the .ga TLD server.
  * Removed the .cd and cf TLD servers.
  * Removed 72 new gTLDs which are no longer active.
* Tue Mar 30 2021 Dirk Müller <dmueller@suse.com>
- update to 5.5.9:
  * Updated the .ga TLD server.
  * Removed the .cd and cf TLD servers.
  * Removed 72 new gTLDs which are no longer active.
* Fri Feb 19 2021 Dirk Müller <dmueller@suse.com>
- update to 5.5.8:
  * Added the .xn--4dbrk0ce (.ישראל, Israel) TLD server.
  * Updated the .ie and .az TLD servers.
  * Updated the list of new gTLDs.
* Sun Oct 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.5.7:
  * Implemented support for CIDR queries to whois.arin.net.
    The old behaviour caused the server to return no results, now when
    querying for ip/length the server returns a result if there is an
    exact match.
* Tue Feb 18 2020 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.6:
  * Added the .xn--q7ce6a (.ລາວ, Lao) TLD server
  * Added the .xn--pgbs0dh (.البحرين, Bahrain) domain
* Sat Feb 15 2020 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.5:
  * Fix the hide string for .sx, which broke many others
* Fri Jan  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.4:
  * Updated the .vu TLD server
  * Updated the list of new gTLDs
  * Added the charset for whois.ripe.net
  * Added support for the referrals in answers from whois.registry.in
  * Implemented support for passing raw $salts$
  * Fixed and updated many hiding string
  * Cleaned up the text and typesetting of the man pages
* Mon Nov 18 2019 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.3:
  * Add the new 2630:0000::/12 IPv6 assigmnent to ARIN
  * Update the .xxx TLD server
  * Update the list of new gTLDs
* Thu Oct 10 2019 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.2:
  * Added the .xn--qxa6a (.ευ, European Union, Greek) TLD server
  * Updated the .td TLD server
* Tue Sep 24 2019 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.1:
  * Update the .ge TLD server
  * Update Spanish translations
* Tue Aug  6 2019 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.5.0:
  * Implemented the -I option to query whois.iana.org and use its
    referrals
  * Automatically generate the version string sent to servers
  * Updated the .zm TLD server
  * Added new recovered IPv4 allocations
- includes changes from 5.4.3:
  * Added the new 2a10:0000::/12 IPv6 assignment to RIPE
- includes changes from 5.4.2:
  * Added the .ss and .xn--mgbah1a3hjkrd (موريتانيا, Mauritania)
    TLD servers
  * Updated the .in TLD and related IDN TLDs servers
  * Updated the .fm TLD server
* Wed Feb 20 2019 Andreas Stieger <andreas.stieger@gmx.de>
- whois 5.4.1:
  * Add the .mw TLD server
* Mon Oct 29 2018 astieger@suse.com
- whois 5.4.0:
  * Add support for the new libxcrypt 4.x.
    This allows mkpasswd to support many modern password hash methods
  * Renam the hash types (i.e. the arguments to -H) to use the
    naming convention established by John the Ripper
  * Make mkpasswd use entropy gathered by crypt_gensalt(3), when
    available
  * Add the .gp TLD server
  * Update the list of new gTLDs
* Tue Jul 24 2018 astieger@suse.com
- whois 5.3.2:
  * Added the .ge TLD server
  * Updated the charset for whois.nic.cl
  * Updated the list of new gTLDs
* Wed May 23 2018 astieger@suse.com
- whois 5.3.1:
  * mkpasswd: support passwords of arbitrary length
  * Added the .ls TLD server
  * Added support for -bzh and -uanic NIC handles
  * Updated the list of new gTLDs
* Mon Jan 29 2018 astieger@suse.com
- whois 5.3.0:
  * Implement querying for ip6.arpa domains
  * Updat the .pr TLD servers
  * Update the list of new gTLDs
* Wed Jan 10 2018 astieger@suse.com
- whois 5.2.20:
  * Added the .mr TLD server
  * Removed the .bs TLD server
  * Updated the .ai, .gh, .gr, .kw, .ls, .ph, .sb, .com.uy and .vn
    TLD servers
* Wed Dec 13 2017 kstreitova@suse.com
- whois 5.2.19:
  * Switched do libidn2
  * Adopted getentropy(2) for mkpasswd on recent Linux
  * Updated the .id and .museum TLD servers
  * Removed the .dj TLD server
- run spec-cleaner
* Wed Sep 20 2017 astieger@suse.com
- whois 5.2.18:
  * Fix querying Verisign registry with parameters
  * Fix return code for queries like "nameserver name.example.com"
- includes changes from 5.2.17:
  * Fix whois referrals for .com, .net, .jobs, .bz, .cc and .tv,
    broken by an ICANN-mandated output change:
    https://www.icann.org/resources/pages/rdds-labeling-policy-2017-02-01-en
  * Add various India NIXI delegated domains TLD servers
  * Updated the list of new gTLDs
* Fri Aug 18 2017 astieger@suse.com
- drop whois-5.2.15-fix-CIDR-with-libidn2.patch, no longer required
  with libidn2 >= 2.0.3
* Fri Jun 16 2017 astieger@suse.com
- whois 5.2.16:
  * Fixed parsing of 6to4 addresses broken in 5.2.15.
  * Updated the .do TLD server.
  * Updated the list of new gTLDs.
* Tue May 23 2017 astieger@suse.com
- build with libidn2 for IDNA 2008 support FATE#321897
- fix CIDR notation and also convert using IDNA 2008 transitional
  bsc#1026831, add whois-5.2.15-fix-CIDR-with-libidn2.patch
* Mon Feb 27 2017 astieger@suse.com
- whois 5.2.15:
  * Update the .gf and .mq TLD servers
  * Update the list of new gTLDs
  * Update the charset for whois.nic.kz
  * Fix minor compiler warnings with no practical effects
  * Support for libidn2 is upstream FATE#321897
    remove whois-5.2.14-IDNA2008.patch
    But disable to fix bsc#1026831
* Mon Feb  6 2017 astieger@suse.com
- add support for IDNA2008 and build with libidn2 FATE#321897
  add whois-5.2.14-IDNA2008.patch
* Thu Jan 19 2017 astieger@suse.com
- whois 5.2.14:
  * Updated the .ar, .bm and .fm TLD servers.
  * Updated the Afilias hiding string to fix hiding for the new .bm
    server.
* Tue Nov 15 2016 astieger@suse.com
- whois 5.2.13:
  * Use "domain" instead of "=" for default verisign-grs queries,
    to ignore the name server names spam.
  * Fixed make_ip_del_recovered.pl, which generated non-functioningi
    data.
  * Added the .xn--90ae (бг, Bulgaria) TLD server.
  * Updated the .bd, .jobs and .mobi TLD servers.
  * Added new ASN allocations.
  * Added new recovered IPv4 allocations.
  * Updated the crsnic.net hiding string to fix hiding for .bi.
  * Updated the list of new gTLDs.
* Mon Apr  4 2016 astieger@suse.com
- whois 5.2.12:
  * Added the .xn--e1a4c (ею, European Union) and .xn--mix891f (澳門,
    Macao) TLD servers.
  * Updated the .jobs, .kn and .pro TLD servers.
  * Updated the .gi, .lc, .sc and .vc TLD servers, because the precedent
    data caused the program to return an error status.
  * Updated the list of new gTLDs.
  * Fixed the code which queries whois.iana.org for TLDs to
    recognize IDN TLDs too.
* Tue Dec  8 2015 astieger@suse.com
- whois 5.2.11:
  * Fixed the --select-types and --sources long options.
  * Updated the list of new gTLDs.
  * Removed the .an TLD.
  * Removed the .xn--l1acc (.МОН, Mongolia) TLD server.
  * Added the .xn--mgbtx2b (عراق, Iraq) and .xn--qxam (.ΕΛ, Greece)
    TLD servers.
* Tue Aug 11 2015 astieger@suse.com
- whois 5.2.10:
  * Updated the list of new gTLDs.
  * Updated the .ki and .vg TLD servers.
* Mon Jun  8 2015 astieger@suse.com
- whois 5.2.9:
  * Updated the list of new gTLDs.
  * Updated the .bn and .cr TLD servers.
  * Updated IDSTRING to 5.2.
* Tue May 19 2015 astieger@suse.com
- whois 5.2.8:
  * Updated the list of new gTLDs.
  * Added new ASN allocations.
  * Added the .xn--y9a3aq (.հայ, Armenia) TLD server.
* Thu Mar 26 2015 astieger@suse.com
- whois 5.2.7:
  * Removed a bogus disclaimer detection string.
  * Updated the list of new gTLDs
* Mon Mar 23 2015 astieger@suse.com
- whois 5.2.6:
  * Added the .edu.ph TLD server.
  * Removed the .gov.py TLD server.
  * Updated the list of new gTLDs.
  * Implemented hiding multiple disclaimers blocks to improve
    detection.
  * Updated the disclaimer detection strings.
* Tue Mar  3 2015 astieger@suse.com
- whois 5.2.5:
  * Added the .xn--90ais (.бел, Belarus) TLD server.
  * Updated the .ky TLD server.
  * Updated the list of new gTLDs.
  * Added new recovered IPv4 allocations.
* Sun Jan 25 2015 andreas.stieger@gmx.de
- whois 5.2.4:
  * Fixed referrals handling for the .cc, .tv a .jobs TLDs.
  * Updated the list of new gTLDs.
* Thu Jan 22 2015 andreas.stieger@gmx.de
- whois 5.2.3:
  * Added the .gw TLD server.
  * Updated the .bm, .gr, .gt, .md, .np, .py, .tc, .tg, .vi,
    .net.za, .org.za and .web.za TLD servers.
  * Removed the .cg TLD server.
  * Updated the list of new gTLDs.
  * mkpasswd: use arc4random_buf(3) where available.
  * mkpasswd: support OpenBSD's new hash 2b.
  * Updated some IPv4 allocations.
* Sat Dec  6 2014 crrodriguez@opensuse.org
- whois-nobsdsource.patch: get rid of warnings about
  BSD_SOURCE deprecatation , just define GNU_SOURCE
  globally instead of any other C library feature macro.
* Thu Nov 13 2014 andreas.stieger@gmx.de
- whois 5.2.2:
  * Fixed the code that removes trailing dots.
  * Added the .xn--d1alf (.мкд, Macedonia) and .xn--node (.გე,
    Georgia) TLD servers.
  * Updated the list of new gTLDs.
- make perl requirements explict.
- In 13.1, perl(autodie) is provided by the main perl package, do
  not look at the alternative in perl-autodie.
* Thu Oct 16 2014 andreas.stieger@gmx.de
- whois 5.2.1:
  * Added the .aw and .zm TLD servers.
  * Added the charset for whois.domain.kg.
  * Updated the list of new gTLDs.
  * Queries for bare TLDs will be directed to whois.iana.org.
* Sat Sep 13 2014 andreas.stieger@gmx.de
- whois 5.2.0:
  * Implemented support for the long RIPE flags.
  * "Fixed" some harmless bugs discovered with a Coverity scan.
  * Default to whois.ripe.net when using long flags.
  * Updated the list of new gTLDs.
  * Added a new ASN allocation.
  * Added new recovered IPv4 allocations.
* Sun Aug  3 2014 andreas.stieger@gmx.de
- whois 5.1.5:
  * Updated the list of new gTLDs.
  * Added some disclaimer suppression strings for the new gTLDs'
    servers.
* Wed Jul  2 2014 andreas.stieger@gmx.de
- whois 5.1.4:
  * Added the charset for whois.lacnic.net.
  * Updated the list of new gTLDs.
  * Updated one or more translations.
- remove source URL from upstream keyring as it changes with
  signatures added
* Mon May 26 2014 andreas.stieger@gmx.de
- whois 5.1.3:
  * Use the IANA recovered address space list.
  * Updated the list of new gTLDs.
  * Support hiding disclaimers until the end of the output.
  * Fix a disclaimer hiding string.
* Sat May  3 2014 andreas.stieger@gmx.de
- whois 5.1.2:
  * Always query whois.nic.$TLD for the "new" gTLDs, because the
    ICANN  contract requires that it works.
  * Added the .aw and .zm TLD servers.
  * Updated the .mk, .tc and .vu TLD servers.
  * Added more ASN entries for Japan and Korea.
  * Fixed some invalid ASN and networks entries which would never
    be matched
- drop whois-5.0.25-nb.patch, committed upstream
- update upstream developer signing key
- use parallel build
* Sun Jan 12 2014 andreas.stieger@gmx.de
- update to 5.1.1
  * Added the servers for 29 "new" gTLDs.
* Fri Dec 27 2013 andreas.stieger@gmx.de
- update to 5.1.0
  * Added the .ga, .ml, .pf, .xn--l1acc (.МОН, Mongolia) and
  .xn--mgba3a4f16a (.ﺍیﺭﺎﻧ, Iran) TLD servers.
  * Added the servers for 54 "new" gTLDs.
  * Updated the .bw, .gd, .hn, .sb, .xn--j1amh and .xn--mgberp4a5d4ar
  TLD servers.
  * Added new RIPE and APNIC ASN allocations.
  * Removed the .ck TLD server.
  * Updated one or more translations.
  * Applied multiple small fixes contributed by Petr Písař of Red Hat.
  * Correctly hide the disclaimers for .be and .sx.
  * Direct queries for private ASN blocks to RIPE.
* Sat Jul 20 2013 andreas.stieger@gmx.de
- update to 5.0.26
  * Added the .cf TLD server.
  * Updated the .bi TLD server.
  * Added a new ASN allocation.
* Tue Jul  9 2013 andreas.stieger@gmx.de
- verify source signatures
* Tue Jul  9 2013 andreas.stieger@gmx.de
- update to 5.0.25
  * Added the .ax, .bn, .iq, .pw and .rw TLD servers.
  * Updated one or more translations.
- includes updates changes 5.0.24:
  * Merged documentation fixes and the whois.conf(5) man page
  * Added a new ASN allocation.
  * Updated one or more translations.
- includes changes from 5.0.23
  * whois.nic.or.kr switched from EUC-KR to UTF-8.
- includes changes from 5.0.22
  * Fixed cross-compiling
- includes changes from 5.0.21
  * Fixed parsing of 6to4 addresses
  * Added the .xn--j1amh (.укр, Ukraine) TLD server.
  * Updated the .bi, .se and .vn TLD servers.
  * Removed whois.pandi.or.id from the list of servers which support the
    RIPE extensions, since it does not anymore and queries are broken.
  * Updated some disclaimer suppression strings.
  * Respect DEB_HOST_GNU_TYPE when selecting CC for cross-compiling.
- includes changes form 5.0.20
  * Updated the .by, .ng, .om, .sm, .tn, .ug and .vn TLD servers.
  * Added the .bw, .td, .xn--mgb9awbf (عمان., Oman), .xn--mgberp4a5d4ar
    (.السعودية, Saudi Arabia) and .xn--mgbx4cd0ab (ﻢﻠﻴﺴﻳﺍ., Malaysia)
    TLD servers.
  * Removed the .kp, .mc, .rw and .xn--mgba3a4f16a (ایران., Iran) TLD servers.
- includes changes from 5.0.19
  * Added the .post TLD server.
  * Updated the .co.za SLD servers.
  * Added the .alt.za, .net.za and .web.za SLD servers.
  * whois.ua changed (?) the encoding to utf-8.
  * Fixed the parsing of 6to4 addresses like whois 2002:xxxx::.
- includes changes from 5.0.18
  * Updated the .ae and .xn--mgbaam7a8h (.امارات, United Arabs Emirates)
    TLDs.
  * Updated the server charset table for .fr and .it.
- includes changes from whois 5.0.17
  * Updated the .bi, .fo, .gr and .gt TLD servers.
  * Removed support for recursion of .org queries, it has been a thick
    registry since 2005.
- includes changes from 5.0.16
  * Added the .xn--80ao21a (.ҚАЗ, Kazakhstan) TLD server.
  * Updated the .ec and .ee TLD servers.
  * Removed the .xn--mgbc0a9azcg (.المغرب, Morocco) and .xn--mgberp4a5d4ar
    (.السعودية, Saudi Arabia) TLD servers.
  * Added a new ASN allocation.
  * Updated one or more translations.
- includes changes from 5.0.15
  * Added the .xn--mgba3a4f16a (ایران., Iran) TLD server.
  * Updated the .pe TLD server, this time for real.
  * Updated one or more translations.
- includes changes from 5.0.14
  * Added the .sx TLD server.
  * Updated the .pe TLD server.
- includes changes from 5.0.13
  * Updated the .hr TLD server.
  * Improved the package description
  * Updated the FSF address in licenses.
- includes changes from 5.0.12
  * Recursion disabled when the query string contains spaces, because
    probably the query format will not be compatible with the referral
    server (e.g. whois to rwhois or ARIN to RIPE).
  * Add the "+" flag by default to queries to whois.arin.net if the
    argument looks like an IP address. Also add the "a" and "n" flags.
    No thanks to ARIN for breaking every whois client.
  * Added the .cv, .lk, .mq, .sy, .so, .biz.ua, .co.ua, .pp.ua, .qa,
    .xn--3e0b707e (.한국, Korea), .xn--45brj9c (.ভারত, India, Bengali),
    .xn--90a3ac (.СРБ, Serbia), .xn--clchc0ea0b2g2a9gcd (.சிங்கப்பூர்,
    Singapore, Tamil), .xn--fpcrj9c3d (.భారత్, India, Telugu), .xn--fzc2c9e2c
    (.ලංකා, Sri Lanka, Sinhala), .xn--gecrj9c (.ભારત, India, Gujarati),
    .xn--h2brj9c (.भारत, India, Hindi), .xn--lgbbat1ad8j (.الجزائر, Algeria),
    .xn--mgbayh7gpa (.الاردن, Jordan), .xn--mgbbh1a71e (.بھارت, India, Urdu),
    .xn--mgbc0a9azcg (.المغرب, Morocco), .xn--ogbpf8fl (.سورية, Syria),
    .xn--s9brj9c (.ਭਾਰਤ, India, Punjabi), .xn--xkc2al3hye2a (.இலங்கை, Sri
    Lanka, Tamil), .xn--wgbl6a (.قطر, Qatar), .xn--xkc2dl3a5ee0h
    (.இந்தியா, India, Tamil), .xn--yfro4i67o (.新加坡, Singapore, Chinese) and
    .xxx TLD servers. (Closes: #642424),
  * Added the .priv.at pseudo-SLD server.
  * Updated the .co, .gf, .gp, .kr, .li, .rs, .ru, .su, .sv, .ua and
    .xn--p1ai TLD servers. (Closes: #590425, #634830, #627478)
  * Added a new ASN allocation.
  * Fixed a typo and -t syntax in whois(1). (Closes: #614973, #632588)
  * Made whois return an error in some cases, code contributed by
    David Souther.
  * Split HAVE_LINUX_CRYPT_GENSALT from HAVE_XCRYPT to support SuSE,
    which has it builtin in the libc. Added untested support for Solaris'
    crypt_gensalt(3). This and the following changes have been contributed
    by Ludwig Nussel of SuSE.
  * mkpasswd: stop rejecting non-ASCII characters.
  * mkpasswd: added support for the 2y algorithm, which fixes CVE-2011-2483.
  * mkpasswd: raised the number of rounds for 2a/2y from 4 to 5, which is
    the current default.
  * mkpasswd: removed support for 2 and {SHA}, which actually are not
    supported by FreeBSD and libxcrypt.
- packaging changes
  * removed patches accepted upstream:
    whois-5.0.11-mkpasswd-support-Owl-patched-libcrypt.diff
    whois-5.0.11-mkpasswd-crypt_gensalt-might-change-the-prefix.diff
    whois-5.0.11-mkpasswd-support-8bit-characters.diff
    whois-5.0.11-mkpasswd-add-support-for-the-new-2y-blowfish-tag-CVE-2011-2483.diff
    whois-5.0.11-mkpasswd-set-default-blowfish-rounds-to-5.diff
    whois-5.0.11-mkpasswd-remove-obsolete-settings.diff
  * removed patches no longer required:
    whois-5.0.11-mkpasswd-fix-compiler-warnings.diff
  * updated patches:
    whois-4.7.33-nb.patch to whois-5.0.25-nb.patch
* Thu Jul  4 2013 schwab@suse.de
- crypt_gensalt moved to separate library libowcrypt (fate#314945)
* Fri Aug 26 2011 lnussel@suse.de
- fix build on older distros
* Tue Jul 19 2011 lnussel@suse.de
- enable use of crypt_gensalt to support all glibc supported
  algorithms
- allow 8bit passwords read from file
- support new blowfish $2y algorithm
* Tue Mar 22 2011 puzel@novell.com
- update to whois-5.0.11
  * Added the remaining IPv4 allocations.
  * Added new ASN allocations.
  * Updated the .co and .gm TLD servers.
- run spec-cleaner
* Wed Dec  1 2010 puzel@novell.com
- update to whois-5.0.10
  * updated IPv4 allocations and TLD servers
* Fri Oct  1 2010 puzel@novell.com
- build with iconv support (bnc#642681)
* Mon Aug  9 2010 puzel@novell.com
- update to whois-5.0.7
  * Added new IPv4 allocations.
  * Added the new TLD servers.
  * Updated the .bd, .bo, .cm, .co, .cu, .dz, .gr, .hk, .lb,
    .ni, .rw, .tw and .tz TLD servers.
* Mon Jul 19 2010 puzel@novell.com
- update to whois-5.0.6
  * Added new IPv4 allocations.
  * Stop using inet_pton to parse IP addresses because it does
    not work when a netmask length is specified.
  * Updated translations.
* Mon Jan  4 2010 puzel@novell.com
- update to whois-5.0.0
  * Added optional support for automatically transcoding the
    output of servers.
  * Automatically add --show-handles to queries for .dk domains.
  * Normalize the querystring and convert it to punycode even if a
    server is specified on the command line.
  * Updated the .id, .is, .my, .sb and .tj TLD servers.
  * Removed the .mm, .pw, .sr and .tp TLD servers.
  * Cleaned up the horrible strings manipulation code.
* Thu Aug 13 2009 puzel@novell.com
- update to whois-4.7.36
  * Fixed the whois server for 182.0.0.0/7 added in 4.7.35.
  * Fixed the whois servers for some ERX legacy allocations.
  * Added new IPv4 allocations.
  * Updated the .ae, .jobs, .ms, .ph and .tv TLD servers.
  * Added the .ls, .mg, .mk, .tz and .uy TLD servers.
  * Removed the .td TLD server.
  * mkpasswd: generate random-length hashes when supported.
  * mkpasswd: use ngettext to support translation of plural forms.
    (Patch courtesy of Petr Pisar.)
  * Updated some translations.
* Tue Jun 23 2009 puzel@novell.com
- update to whois-4.7.34
  * Added new IPv4 allocations.
  * Fixed the disclaimer suppression data for .mobi.
  * Updated the French translation.
  * Updated the .bd TLD server.
* Mon May  4 2009 puzel@suse.cz
- updated to version 4.7.33
  * mkpasswd: use /dev/urandom to generate the salt. If it is not present,
    initialize srand(3) with gettimeofday(2) instead of time(2) to have a
    larger randomness space.
  * mkpasswd: added preliminary support for variable length salts, patch
    courtesy of Nicolas François.
  * Updated the .co.za SLD server.
  * Added new ASN allocations.
  * Updated the .tel, .gg and .je TLD servers.
  * Implemented a 10 seconds timeout on connect(2) to allow querying
    servers with broken IPv6 connectivity.
  * Added support for automatically determining the server for in-addr.arpa
    domains.
  * Added new IPv4 allocations.
  * Fixed a typo in de.po.
  * Updated the .gi, .lc and .mn TLD servers.
  * Fixed the short option -S which I broke in 4.7.25.
  * Added support for ASN32 in the ASPLAIN notation.
  * Do not disable the timeout after the connection to the server, because
    it can still hang forever.
  * Added the .gy, .hn, .ng and .sl TLD servers.
  * Updated the .tel, .cr, .dz, .ht, .im, .jo, .ly, .mt, .mu, .pr, .rs, .sn,
    .com.uy, .vc and .vn TLD servers.
  * Added support for -kenic NIC handles.
  * Added new IPv4 allocations.
  * Little portability fixes.
  * Added Finnish translation contributed by Sami Kerola.
- removed whois-4.7.28-Makefile.patch (obsolete)
- fixed rpmlint warning
- properly pass RPM_OPT_FLAGS to make
* Fri Sep 12 2008 anosek@suse.cz
- updated to version 4.7.28
  * Updated the .aero TLD server.
  * Added a new ASN allocation.
  * Search PGPKEY-* objects in the RIPE database.
  * Added support for passing command line options in the environment
    variables WHOIS_OPTIONS and MKPASSWD_OPTIONS.
  * mkpasswd: added support for the SHA-256 and SHA-512 methods from
    glibc 2.7.
  * mkpasswd: added support for FreeBSD-style Blowfish and NT-Hash methods.
  * mkpasswd: added support for variable-rounds methods (OpenBSD-style
    Blowfish and SHA-256/SHA-512).
  * mkpasswd: renamed -H/--hash to -m/--method.
  * mkpasswd: finished support for libxcrypt (not enabled by default).
- fixed build (Makefile.patch)
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-in-lang errors
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 4.7.24
  * Added new ASN allocations.
  * Added new IPv4 allocations.
  * Added the .asia, .kp and .mq TLD servers. (Closes: #445747)
  * Fixed myinet_aton to not reject CIDR networks.
  * Added support for ASN32.
  * Added the za.net and za.org pseudo-TLD servers.
  * Added new IPv4 allocations.
  * Added new ASN allocations.
  * Updated the .jobs, .ai and .tn TLD and za.net servers.
  * Added the za.net server. (Closes: #423549)
  * Stop misparsing <as-set>:<hierarchical-name> as an IPv6 address.
  * Stop mangling IDN queries with in-query flags. (Closes: #422895)
* Tue Jul 31 2007 anosek@suse.cz
- updated to version 4.7.21
  * Improved myinet_aton to not parse addresses with trailing junk
  * Added APNIC and RIPE allocations.
  * Updated the name of the Verio whois server. (Closes: #410449)
  * Removed references to whois.nic.mil, which apparently is gone.
  * Removed whois.nic.it from ripe_servers, because it does not even
    pretend to be one anymore.
* Mon Feb  5 2007 anosek@suse.cz
- updated to version 4.7.20
  * Added more krnic allocations.
  * Added support for -sixxs NIC handles.
  * Added again 26[12]0:0000::/23 which had been mistakenly removed
  * Added new IPv4 and IPv6 allocations.
  * whois.radb.net does not understand the RIPE protocol anymore.
  * Added support for IPv6 Teredo addresses, contributed by Rémi
    Denis-Courmont. (Closes: #384373)
  * Updated the .mobi and .gs TLD servers.(Closes: #389880, 391447)
  * Added the .gd TLD server.
* Wed Sep 20 2006 anosek@suse.cz
- updated to version 4.7.17
  * Added new IPv4 and IPv6 allocations.
  * Strip the CIDR prefix length from queries to whois.arin.net.
* Thu Aug  3 2006 mmarek@suse.cz
- updated to version 4.7.15
  * TLD server list updates
  * new translations
- no need to patch top level Makefile
* Fri Apr 14 2006 mmarek@suse.cz
- updated the tld_serv_list file to include .eu and other new TLDs
  [#165904] (tld_serv_list-4.7.13.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep  9 2005 schwab@suse.de
- Add libidn, libidn-devel to nfb.
- Compile with -DHAVE_LIBIDN, needed for DENIC workaround.
* Fri Jul 29 2005 anicka@suse.cz
- update to 4.7.5
* Thu Jan 13 2005 postadal@suse.cz
- updated to version 4.6.26
* Wed Oct 20 2004 ro@suse.de
- locale rename: no -> nb
* Thu Aug 19 2004 postadal@suse.cz
- updated to version 4.6.20u
* Fri Aug  6 2004 postadal@suse.cz
- updated to version 4.6.19
* Wed Feb 11 2004 postadal@suse.cz
- updated to version 4.6.9
- added changelog and copyright files
- removed obsoleted patch buffoverflow-fix
* Thu Oct 30 2003 schwab@suse.de
- Fix for 64 bit platforms.
* Thu Aug 28 2003 postadal@suse.cz
- fixed buffer overflow [#29511]
* Thu Jul 24 2003 postadal@suse.cz
- updated to version 4.6.6
  * added .dj TLD
  * fixed netsol disclaimer strings
  * updated PIR server parser
* Mon Feb  3 2003 postadal@suse.cz
- updated to version 4.6.2
* Mon Aug 12 2002 postadal@suse.cz
- update to 4.5.29:
  * updated LANIC and telstra IP allocations
  * updated mkpasswd
  * fixes
* Fri Jan 18 2002 nadvornik@suse.cz
- update to 4.5.19:
  - updated .aero, .coop, .name, .pro, .dk and .edu TLD servers
* Mon Dec 10 2001 nadvornik@suse.cz
- update to 4.5.15:
  - updated translations
  - bugfixes
* Thu Jul 26 2001 nadvornik@suse.cz
- update to 4.5.6
* Tue Mar 27 2001 nadvornik@suse.cz
- update to 4.5.4
* Thu Dec  7 2000 uli@suse.de
- update -> 4.5.1 (doesn't segfault)
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
* Fri May 19 2000 nadvornik@suse.cz
- update to 4.4.13
- changed group
* Thu Mar 30 2000 nadvornik@suse.cz
- update to 4.4.12
- added BuildRoot
- added %%{_mandir} macro
* Fri Mar  3 2000 uli@suse.de
- moved man pages to /usr/share
* Mon Feb 21 2000 mha@suse.de
- completely new, different version from
  http://www.linux.it/~md/software/
  Quote README of the new version:
  "Why another whois client? Because the RIPE client is a mess of
  hacks and #ifdefs and more complex programs lack features or
  are bloated."
* Mon Nov 29 1999 kukuk@suse.de
- fixed for SPARC
* Tue Sep 21 1999 uli@suse.de
- fixed for PPC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Feb  2 1999 ro@suse.de
- use libcrypt on alpha
- no m486 on alpha
* Thu Oct  1 1998 ro@suse.de
- defined _BSD_SOURCE
- dont redeclare gethostname
- link with -crypt where needed
* Tue May 27 1997 florian@suse.de
- first version of ripe-whois 2.2
